@@ -1,14 +1,14 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-1999, Patrick Powell, San Diego, CA
- *     papowell@astart.com
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
+ *     papowell@lprng.com
  * See LICENSE for conditions of use.
  *
  ***************************************************************************/
 
  static char *const _id =
-"$Id: copyright.c,v 5.1 1999/09/12 21:32:33 papowell Exp papowell $";
+"$Id: copyright.c,v 1.74 2004/09/24 20:19:57 papowell Exp $";
 
 
 #include "lp.h"
@@ -16,8 +16,15 @@
 /**** ENDINCLUDE ****/
 
 char *Copyright[] = {
-"LPRng version " PATCHLEVEL "",
-"Author: Patrick Powell, <papowell@astart.com>",
+ PATCHLEVEL
+#if defined(KERBEROS)
+ ", Kerberos5"
+#endif
+#if defined(MIT_KERBEROS4)
+ ", MIT Kerberos4"
+#endif
+", Copyright 1988-2003 Patrick Powell, <papowell@lprng.com>",
+
 "",
 "locking uses: "
 #ifdef HAVE_FCNTL
@@ -41,6 +48,12 @@ char *Copyright[] = {
             "termios"
 #endif
 ,
+#ifdef SSL_ENABLE
+"with SSL"
+#else
+"without SSL"
+#endif
+,
 "",
 #include "license.h"
 #include "copyright.h"
