@@ -1,14 +1,14 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-2002, Patrick Powell, San Diego, CA
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
  *
  ***************************************************************************/
 
  static char *const _id =
-"$Id: utilities.c,v 1.27 2002/04/01 17:54:56 papowell Exp $";
+"$Id: utilities.c,v 1.74 2004/09/24 20:19:59 papowell Exp $";
 
 #include "lp.h"
 
@@ -85,7 +85,7 @@ char *Pretty_time( time_t t )
 		t = tv.tv_sec;
 	}
 	tmptr = localtime( &t );
-	strftime( buffer, sizeof(buffer), "%b %d %R %Y", tmptr );
+	strftime( buffer, sizeof(buffer), "%b %d %H:%M:%S %Y", tmptr );
 
 	return( buffer );
 }
@@ -222,13 +222,14 @@ int Read_fd_len_timeout( int timeout, int fd, char *msg, int len )
 	if( timeout > 0 ){
 		if( Set_timeout() ){
 			Set_timeout_alarm( timeout  );
-			i = read( fd, msg, len );
+			i = ok_read( fd, msg, len );
 		} else {
 			i = -1;
+			errno = EINTR;
 		}
 		Clear_timeout();
 	} else {
-		i = read( fd, msg, len );
+		i = ok_read( fd, msg, len );
 	}
 	return( i );
 }
@@ -491,7 +492,8 @@ int plp_usleep( int i )
 	DEBUG3("plp_usleep: starting usleep %d", i );
 	if( i > 0 ){
 		memset( &t, 0, sizeof(t) );
-		t.tv_usec = i;
+		t.tv_usec = i%1000000;
+		t.tv_sec =  i/1000000;
 		i = select( 0,
 			FD_SET_FIX((fd_set *))(0),
 			FD_SET_FIX((fd_set *))(0),
@@ -539,6 +541,13 @@ int Get_max_servers( void )
 		FATAL(LOG_ERR) "Get_max_servers: getrlimit failed" );
 	}
 	n = pcount.rlim_cur;
+#ifdef RLIMIT_INFINITY
+	if( pcount.rlim_cur == RLIM_INFINITY ){
+		n = Max_servers_active_DYN;
+		DEBUG1("Get_max_servers: using %d", n );
+	}
+#endif
+
 	DEBUG1("Get_max_servers: getrlimit returns %d", n );
 #else
 # if defined(HAVE_SYSCONF) && defined(_SC_CHILD_MAX)
@@ -551,14 +560,18 @@ int Get_max_servers( void )
 		n = CHILD_MAX;
 		DEBUG1("Get_max_servers: CHILD_MAX %d", n );
 #  else
-		n = 20;
+		n = 0;
 		DEBUG1("Get_max_servers: default %d", n );
 #  endif
 # endif
 #endif
-	n = n/2;
+	n = n/4;
+	if(( n > 0 && n > Max_servers_active_DYN)
+		|| (n <= 0 && Max_servers_active_DYN) ){
+		n = Max_servers_active_DYN;
+	}
+	if( n <= 0 ) n = 32;
 
-	if( Max_servers_active_DYN && n > Max_servers_active_DYN ) n = Max_servers_active_DYN;
 	DEBUG1("Get_max_servers: returning %d", n );
 	return( n );
 }
@@ -592,7 +605,7 @@ int Get_max_fd( void )
 # endif
 #endif
 
-	if( n < 0 || n > 10240 ){
+	if( n <= 0 || n > 10240 ){
 		/* we have some systems that will return a VERY
 		 * large or negative number for unlimited FD's.  Well, we
 		 * don't want to use a large number here.  So we
@@ -803,7 +816,7 @@ int Read_write_timeout(
 		} else {
 			if( FD_ISSET( readfd, &readfds ) ){
 				DEBUG4("Read_write_timeout: read possible on fd %d", readfd );
-				m = read( readfd, inbuffer, maxinlen );
+				m = ok_read( readfd, inbuffer, maxinlen );
 				DEBUG4("Read_write_timeout: read() returned %d", m );
 				if( readlen ) *readlen = m;
 				/* caller leaves space for this */
@@ -1435,32 +1448,32 @@ void Reset_daemonuid(void)
 #  define plp_struct_statfs struct statvfs
 #  define statfs(path, buf) statvfs(path, buf)
 #  define USING "STATVFS"
-#  define BLOCKSIZE(f) (unsigned long)(f.f_frsize?f.f_frsize:f.f_bsize)
-#  define BLOCKS(f)    (unsigned long)f.f_bavail
+#  define BLOCKSIZE(f) (double)(f.f_frsize?f.f_frsize:f.f_bsize)
+#  define BLOCKS(f)    (double)f.f_bavail
 # endif
 
 # if USE_STATFS_TYPE == ULTRIX_STATFS
 #  define plp_statfs(path,buf) statfs(path,buf)
 #  define plp_struct_statfs struct fs_data
 #  define USING "ULTRIX_STATFS"
-#  define BLOCKSIZE(f) (unsigned long)f.fd_bsize
-#  define BLOCKS(f)    (unsigned long)f.fd_bfree
+#  define BLOCKSIZE(f) (double)f.fd_bsize
+#  define BLOCKS(f)    (double)f.fd_bfree
 # endif
 
 # if USE_STATFS_TYPE ==  SVR3_STATFS
 #  define plp_struct_statfs struct statfs
 #  define plp_statfs(path,buf) statfs(path,buf,sizeof(struct statfs),0)
 #  define USING "SV3_STATFS"
-#  define BLOCKSIZE(f) (unsigned long)f.f_bsize
-#  define BLOCKS(f)    (unsigned long)f.f_bfree
+#  define BLOCKSIZE(f) (double)f.f_bsize
+#  define BLOCKS(f)    (double)f.f_bfree
 # endif
 
 # if USE_STATFS_TYPE == STATFS
 #  define plp_struct_statfs struct statfs
 #  define plp_statfs(path,buf) statfs(path,buf)
 #  define USING "STATFS"
-#  define BLOCKSIZE(f) (unsigned long)f.f_bsize
-#  define BLOCKS(f)    (unsigned long)f.f_bavail
+#  define BLOCKSIZE(f) (double)f.f_bsize
+#  define BLOCKS(f)    (double)f.f_bavail
 # endif
 
 
