@@ -1,10 +1,10 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-2002, Patrick Powell, San Diego, CA
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: lp.h,v 1.27 2002/04/01 17:54:57 papowell Exp $
+ * $Id: lp.h,v 1.74 2004/09/24 20:20:00 papowell Exp $
  ***************************************************************************/
 
 
@@ -21,7 +21,6 @@
  *****************************************************************/
 #include "portable.h"
 
-
 /*****************************************************************
  * Global variables and routines that will be common to all programs
  *****************************************************************/
@@ -54,34 +53,6 @@ struct line_list;
 #include "errormsg.h"
 #include "plp_snprintf.h"
 
-/***************************************************************
- * Security stuff - needs to be in a common place
- ***************************************************************/
-
-struct security;
-typedef int (*CONNECT_PROC)( struct job *job, int *sock,
-	char **real_host,
-	int connect_timeout, char *errmsg, int errlen,
-	struct security *security, struct line_list *info );
-
-typedef int (*RECEIVE_PROC)( int *sock, char *user, char *jobsize,
-	int from_server,
-	char *authtype, struct line_list *config,
-	char *error, int errlen, struct line_list *header_info,
-	char *tempfile );
-
-typedef int (*SEND_PROC)( int *sock, int transfer_timeout, char *tempfile,
-	char *error, int errlen,
-	struct security *security, struct line_list *info );
-
-struct security {
-	char *name;				/* authentication name */
-	char *config_tag;		/* use this tag for configuration information */
-	CONNECT_PROC connect;		/* make the connection, talk to verify */
-	SEND_PROC    send;		/* authenticate transfer, talk to transfer */
-	RECEIVE_PROC receive;		/* receive from transfer */
-};
-
 /*****************************************************************
  * General variables use in the common routines;
  * while in principle we could segragate these, it is not worth it
@@ -260,7 +231,6 @@ xxx error - you have already defined ISNULL
 EXTERN char *ShortHost_FQDN;		/* Short hostname for logging */
 EXTERN char *FQDNHost_FQDN;		/* FQDN hostname */
 EXTERN char* FQDNRemote_FQDN;    /* FQDN of Remote host */
-EXTERN char* FQDNRemote_FQDN;    /* FQDN of Remote host */
 EXTERN char* ShortRemote_FQDN;   /* Short form of Remote host */
 /* EXTERN char* Auth_client_id_DYN;	/ * client sent/received authentication info */
 
@@ -269,6 +239,7 @@ EXTERN int Drop_root_DYN;				/* drop root permissions */
 EXTERN int Accounting_check_DYN; /* check accounting at start */
 EXTERN char* Accounting_end_DYN;/* accounting at start (see also af, la, ar) */
 EXTERN char* Accounting_file_DYN; /* name of accounting file (see also la, ar) */
+EXTERN char* Accounting_namefixup_DYN; /* fix up accounting name */
 EXTERN int Accounting_remote_DYN; /* write remote transfer accounting (if af is set) */
 EXTERN char* Accounting_start_DYN;/* accounting at start (see also af, la, ar) */
 EXTERN char* Allow_user_setting_DYN;	/* allow users to set job submitter */
@@ -296,9 +267,9 @@ EXTERN int Check_for_nonprintable_DYN;	/* lpr check for nonprintable file */
 EXTERN int Check_for_protocol_violations_DYN;	/* check for RFC1179 protocol violations */
 EXTERN char* Chooser_DYN;	/* choose the destination for a load balance queue */
 EXTERN int Chooser_interval_DYN;	/* interval between tests for load balance destination */
+EXTERN int Chooser_scan_queue_DYN;	/* scan the queue */
 EXTERN char* Chooser_routine_DYN;	/* choose the destination for a load balance queue */
 EXTERN int Class_in_status_DYN;	/* Show class in status information */
-EXTERN int Client_flag_DYN;	/* Client flag set in printcap information */
 EXTERN char* Comment_tag_DYN; /* comment identifying printer (LPQ) */
 EXTERN char* Config_file_DYN;
 EXTERN int Connect_grace_DYN; /* grace period for reconnections */
@@ -317,12 +288,16 @@ EXTERN char* Default_priority_DYN;	/* default priority */
 EXTERN char* Default_remote_host_DYN;
 EXTERN char* Default_tmp_dir_DYN;	/* default temporary file directory */
 EXTERN char* Destinations_DYN; /* printers that a route filter may return and we should query */
+EXTERN int   Discard_large_jobs_DYN;  /* discard jobs that exceed max job size */
 EXTERN int   Done_jobs_DYN;        /* keep the last NN done jobs */
 EXTERN int   Done_jobs_max_age_DYN; /* keep the done jobs for at least max age seconds */
 EXTERN int Direct_DYN;		/* allow LPR to send jobs to a socket */
 EXTERN int Exit_linger_timeout_DYN;	/* we set this timeout on all of the sockets */
 EXTERN int FF_on_close_DYN; /* print a form feed when device is closed */
 EXTERN int FF_on_open_DYN; /* print a form feed when device is opened */
+EXTERN int Fifo_DYN; /* FIFO (first in first out) order enforced */
+EXTERN char* Fifo_lock_file_DYN; /* lock file for FIFO */
+
 EXTERN char* Filter_DYN; /* default filter */
 EXTERN int   Filter_stderr_to_status_file_DYN; /* filter errors sent to :ps file */
 EXTERN char* Filter_ld_path_DYN;
@@ -364,12 +339,12 @@ EXTERN int Logger_max_size_DYN; /* log record size */
 EXTERN char* Logger_path_DYN; /* path to status log file */
 EXTERN int Logger_timeout_DYN; /* logger timeout size */
 EXTERN char* Logname_DYN;		/* Username for logging */
-EXTERN char* Lpr_opts_DYN;		/* addional options for LPR */
 EXTERN int Long_number_DYN; /* long job number (6 digits) */
-EXTERN int Max_datafiles_DYN; /* maximum datafiles */
-EXTERN int Lpd_bounce_DYN; /* force LPD to do bounce queue filtering */
 EXTERN char* Lp_device_DYN; /* device name or lp-pipe command to send output to */
+EXTERN int Lpd_bounce_DYN; /* force LPD to do bounce queue filtering */
 EXTERN char* Lpd_listen_port_DYN; /* lpd listens on this port, "off" does not open port */
+EXTERN char* Ipp_listen_port_DYN; /* lpd listens on this port, "off" does not open port */
+EXTERN char* Ipp_port_DYN; /* ipp protocol port */
 EXTERN char* Lpd_path_DYN; /* LPD path for server use */
 EXTERN char* Lpd_port_DYN;	/* client/lpd connect to remote (non-local) lpd servers on this port */
 EXTERN char* Lpd_printcap_path_DYN;
@@ -378,13 +353,18 @@ EXTERN char* Lpq_status_file_DYN; /* cached lpq status */
 EXTERN int   Lpq_status_cached_DYN;  /* how many to cache */
 EXTERN int   Lpq_status_interval_DYN;  /* interval between updates */
 EXTERN int   Lpq_status_stale_DYN;  /* cached lpq status is stale after this */
+EXTERN char* Lpr_opts_DYN;		/* addional options for LPR */
+EXTERN int Lpr_send_try_DYN; /* number of times for lpr to try sending job */
 EXTERN char* Mail_from_DYN;
 EXTERN char* Mail_operator_on_error_DYN;
+
+EXTERN int Max_accounting_file_size_DYN;	/* maximum accounting file size */
 EXTERN int Max_connect_interval_DYN;	/* maximum connect interval */
 EXTERN int Max_copies_DYN; /* maximum copies allowed */
+EXTERN int Max_datafiles_DYN; /* maximum datafiles */
 EXTERN int Max_job_size_DYN; /* maximum job size (1Kb blocks, 0 = unlimited) */
-EXTERN int Max_accounting_file_size_DYN;	/* maximum accounting file size */
 EXTERN int Max_log_file_size_DYN;	/* maximum log file size */
+EXTERN int Max_move_count_DYN;	/* maximum number of moves or forwards */
 EXTERN int Max_servers_active_DYN;	/* maximum number of servers active */
 EXTERN int Max_status_line_DYN; /* maximum status line size */
 EXTERN int Max_status_size_DYN;
@@ -394,11 +374,13 @@ EXTERN int Min_printable_count_DYN; /* minimum printable characters for printabl
 EXTERN int Min_status_size_DYN;
 EXTERN int Minfree_DYN; /* minimum space (Kb) to be left in spool filesystem */
 EXTERN int Minfree_DYN; /**/
+
 EXTERN int Ms_time_resolution_DYN;
 EXTERN int Network_connect_grace_DYN; /* grace period for reconnections */
 EXTERN char* New_debug_DYN; /* debug level set for queue handler */
 EXTERN int Nline_after_file_DYN;	/* Put Nxxx after fcfA... line in control file */
-EXTERN int No_FF_separator_DYN; /* string to send for a form feed */
+EXTERN int No_FF_separator_DYN; /* no interfile FF separator */ 
+EXTERN int FF_separator_DYN; /* no interfile FF separator */ 
 EXTERN int Nonblocking_open_DYN; /* nonblocking open on io device */
 EXTERN char* OF_Filter_DYN; /* output filter, run once for all output */
 EXTERN char* OF_filter_options_DYN;
@@ -408,8 +390,13 @@ EXTERN int Page_length_DYN; /* page length (in lines) */
 EXTERN int Page_width_DYN; /* page width (in characters) */
 EXTERN int Page_x_DYN; /* page width in pixels (horizontal) */
 EXTERN int Page_y_DYN; /* page length in pixels (vertical) */
-EXTERN char* Pass_env_DYN;		/* pass these environment variables */
+EXTERN char* Pc_entries_required_DYN;	/* make sure these entries are in PRINTCAP_ENTRY */
+EXTERN char* Pass_env_DYN;	/* pass these environment variables */
+EXTERN char* Pgp_path_DYN;	/* pgp path */
 EXTERN int Poll_time_DYN; /* force polling job queues */
+EXTERN int Poll_start_interval_DYN; /* interval between trying to start servers */
+EXTERN int Poll_servers_started_DYN; /* maximum servers to start at one time */
+EXTERN char* Ppd_file_DYN;	/* ppd file */
 EXTERN char* Pr_program_DYN; /* pr program for p format */
 EXTERN char* Prefix_Z_DYN; /* prefix -Z options on outgoing or filter*/
 EXTERN char* Prefix_option_to_option_DYN; /* prefix option to option, ie, "z,o" */
@@ -449,7 +436,6 @@ EXTERN int Send_query_rw_timeout_DYN;
 EXTERN int Send_try_DYN;
 EXTERN int Sendmail_to_user_DYN;
 EXTERN char* Sendmail_DYN;
-EXTERN int Server_flag_DYN;	/* Server flag set in printcap information */
 EXTERN char* Server_names_DYN; /* names of servers for queue (with ss) */
 EXTERN char* Server_queue_name_DYN; /* name of queue that server serves (with sv) */
 EXTERN char* Server_tmp_dir_DYN;	/* default temporary file directory */
@@ -460,6 +446,12 @@ EXTERN int Socket_linger_DYN;	/* set SO_linger for connections to remote hosts *
 EXTERN char* Spool_dir_DYN; /* spool directory (only ONE printer per directory!) */
 EXTERN int Spool_dir_perms_DYN;
 EXTERN int Spool_file_perms_DYN;
+EXTERN char *Ssl_ca_file_DYN;	/* ssl cert file */
+EXTERN char *Ssl_ca_path_DYN;	/* ssl cert directory (path) */
+EXTERN char *Ssl_crl_file_DYN;	/* ssl crl cert directory (path) */
+EXTERN char *Ssl_crl_path_DYN;	/* ssl crl cert directory (path) */
+EXTERN char *Ssl_server_cert_DYN;	/* ssl server cert file */
+EXTERN char *Ssl_server_password_file_DYN;	/* ssl server password file */
 EXTERN int Stalled_time_DYN; /* amount of time before reporing stalled job */
 EXTERN char* Status_file_DYN; /* printer status file name */
 EXTERN int Stop_on_abort_DYN; /* stop when job aborts */
@@ -474,6 +466,7 @@ EXTERN int Use_queuename_DYN;	/* put queuename in control file */
 EXTERN int Use_queuename_flag_DYN;	/* Specified with the -Q option */
 EXTERN int Use_shorthost_DYN;	/* Use short hostname in control file information */
 EXTERN char* User_printcap_DYN;	/* Allow a ${HOME}/.printcap file - name of file*/
+EXTERN int User_is_authuser_DYN;	/* set user to be authentication user value */ 
 EXTERN char* Xlate_incoming_format_DYN;	/* translate format ids on incoming jobs */
 EXTERN char* Xlate_format_DYN;	/* translate format ids on outgoing jobs */
 
@@ -482,4 +475,6 @@ EXTERN char* Xlate_format_DYN;	/* translate format ids on outgoing jobs */
 extern int dmalloc_outfile;
 #endif
 
+#define ok_read read
+
 #endif
