@@ -1,10 +1,10 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-2002, Patrick Powell, San Diego, CA
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: lpd_dispatch.h,v 1.27 2002/04/01 17:54:58 papowell Exp $
+ * $Id: lpd_dispatch.h,v 1.74 2004/09/24 20:20:00 papowell Exp $
  ***************************************************************************/
 
 
@@ -13,8 +13,9 @@
 #define _LPD_DISPATCH_H_ 1
 
 /* PROTOTYPES */
-void Dispatch_input(int *talk, char *input );
+void Dispatch_input(int *talk, char *input, const char *from_addr );
 void Service_all( struct line_list *args );
 void Service_connection( struct line_list *args );
+void Service_lpd( int talk, const char *from_addr );
 
 #endif
