@@ -1,10 +1,10 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-2002, Patrick Powell, San Diego, CA
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: portable.h,v 1.27 2002/04/01 17:54:58 papowell Exp $
+ * $Id: portable.h,v 1.74 2004/09/24 20:20:00 papowell Exp $
  ***************************************************************************/
 
 #ifndef _PLP_PORTABLE_H
@@ -640,10 +640,13 @@ XX ** NO VARARGS ** XX
 #if defined(HPUX) && HPUX<110
 #  undef NONBLOCK
 #  define NONBLOCK (O_NONBLOCK)
-#  undef FD_SET_FIX
-#  define FD_SET_FIX(X) (int *)
 #endif
 
+/* fix for HPUX systems with no fd_set values */
+#undef FD_SET_FIX
+#if !defined(HAVE_FD_SET) && defined(HPUX)
+#  define FD_SET_FIX(X) (int *)
+#endif
 
 
 /*********************************************************************
@@ -808,6 +811,8 @@ extern int openlog( const char *ident, int logopt, int facility );
 
 #ifdef IS_AIX32
 extern int seteuid(uid_t);
+extern int setruid(uid_t);
+extern int setenv(char *, char *, int);
 #endif
 
 
