@@ -1,10 +1,10 @@
 /***************************************************************************
  * LPRng - An Extended Print Spooler System
  *
- * Copyright 1988-1999, Patrick Powell, San Diego, CA
- *     papowell@astart.com
+ * Copyright 1988-2003, Patrick Powell, San Diego, CA
+ *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: sendmail.h,v 5.1 1999/09/12 21:33:09 papowell Exp papowell $
+ * $Id: sendmail.h,v 1.74 2004/09/24 20:20:01 papowell Exp $
  ***************************************************************************/
 
 
@@ -13,7 +13,6 @@
 #define _SENDMAIL_1_ 1
 
 /* PROTOTYPES */
-
-void Sendmail_to_user( int status, struct job *job );
+void Sendmail_to_user( int retval, struct job *job );
 
 #endif
